@@ -162,7 +162,8 @@ static const char usage[] = {
     "1. convert geographical input to UTM zone 32 on the GRS80 ellipsoid:\n"
     "    cct +proj=utm +ellps=GRS80 +zone=32\n"
     "2. roundtrip accuracy check for the case above:\n"
-    "    cct +proj=pipeline +proj=utm +ellps=GRS80 +zone=32 +step +step +inv\n"
+    "    cct +proj=pipeline +ellps=GRS80 +zone=32 +step +proj=utm \\\n"
+    "        +step +proj=utm +inv\n"
     "3. as (1) but specify input columns for longitude, latitude, height and "
     "time:\n"
     "    cct -c 5,2,1,4  +proj=utm +ellps=GRS80 +zone=32\n"
