@@ -69,7 +69,7 @@ opt_given (o, option):
 opt_arg (o, option):
         A char pointer to the argument for <option>
 
-The 2 additional functions (of which, one is really a macro) implements
+An additional function "opt_input_loop" implements
 a "read all operands sequentially" functionality, eliminating the need to
 handle open/close of a sequence of input files:
 
@@ -78,9 +78,6 @@ enum OPTARGS_FILE_MODE:
 opt_input_loop (o, mode):
         When used as condition in a while loop, traverses all operands,
         giving the impression of reading just a single input file.
-opt_eof_handler (o):
-        Auxiliary macro, to be called inside the input loop after each
-        read operation
 
 Usage is probably easiest understood by a brief textbook style example:
 
@@ -112,8 +109,8 @@ int main(int argc, char **argv) {
 
 
     if (opt_given (o, "h")) {
-        printf ("Usage: %s [-v|--verbose] [-h|--help] [-o|--output <filename>] [--hello=<name>] infile...", o->progname);
-        exit (0);
+        printf ("Usage: %s [-v|--verbose] [-h|--help] [-o|--output <filename>]
+[--hello=<name>] infile...", o->progname); exit (0);
     }
 
     if (opt_given (o, "v"))
@@ -125,7 +122,8 @@ int main(int argc, char **argv) {
     }
 
     if (opt_given (o, "o"))
-        out = fopen (opt_arg (o, "output"), "rt"); // Note: "output" translates to "o" internally
+        out = fopen (opt_arg (o, "output"), "rt"); // Note: "output" translates
+to "o" internally
 
     // Setup transformation
     P = proj_create_argv (0, o->pargc, o->pargv);
@@ -134,11 +132,13 @@ int main(int argc, char **argv) {
     while (opt_input_loop (o, optargs_file_format_text)) {
         char buf[1000];
         int ret = fgets (buf, 1000, o->input);
-        opt_eof_handler (o);
-        if (nullptr==ret) {
-            fprintf (stderr, "Read error in record %d\n", (int) o->record_index);
+        if (opt_eof (o)) {
             continue;
         }
+        if (nullptr==ret) {
+            fprintf (stderr, "Read error in record %d\n", (int)
+o->record_index); continue;
+        }
         do_what_needs_to_be_done (buf);
     }
 
@@ -193,70 +193,80 @@ Thomas Knudsen, thokn@sdfe.dk, 2016-05-25/2017-09-10
 /**************************************************************************************************/
 struct OPTARGS;
 typedef struct OPTARGS OPTARGS;
-enum OPTARGS_FILE_FORMAT {optargs_file_format_text = 0, optargs_file_format_binary = 1};
+enum OPTARGS_FILE_FORMAT {
+    optargs_file_format_text = 0,
+    optargs_file_format_binary = 1
+};
 
-char *opt_filename (OPTARGS *opt);
-static int opt_eof (OPTARGS *opt);
-int opt_record (OPTARGS *opt);
-int opt_input_loop (OPTARGS *opt, int binary);
-static int opt_is_flag (OPTARGS *opt, int ordinal);
-static int opt_raise_flag (OPTARGS *opt, int ordinal);
-static int opt_ordinal (OPTARGS *opt, const char *option);
-int opt_given (OPTARGS *opt, const char *option);
-char *opt_arg (OPTARGS *opt, const char *option);
-const char *opt_strip_path (const char *full_name);
-OPTARGS *opt_parse (int argc, char **argv, const char *flags, const char *keys, const char **longflags, const char **longkeys);
+char *opt_filename(OPTARGS *opt);
+static int opt_eof(OPTARGS *opt);
+int opt_record(OPTARGS *opt);
+int opt_input_loop(OPTARGS *opt, int binary);
+static int opt_is_flag(OPTARGS *opt, int ordinal);
+static int opt_raise_flag(OPTARGS *opt, int ordinal);
+static int opt_ordinal(OPTARGS *opt, const char *option);
+int opt_given(OPTARGS *opt, const char *option);
+char *opt_arg(OPTARGS *opt, const char *option);
+const char *opt_strip_path(const char *full_name);
+OPTARGS *opt_parse(int argc, char **argv, const char *flags, const char *keys,
+                   const char **longflags, const char **longkeys);
 
-#define opt_eof_handler(opt) if (opt_eof (opt)) {continue;} else {;}
 /**************************************************************************************************/
 
 struct OPTARGS {
-    int    argc,   margc,   pargc,   fargc;
+    int argc, margc, pargc, fargc;
     char **argv, **margv, **pargv, **fargv;
     FILE *input;
-    int   input_index;
-    int   record_index;
-    const char  *progname;   /* argv[0], stripped from /path/to, if present */
-    char   flaglevel[21];    /* if flag -f is specified n times, its optarg pointer is set to flaglevel + n */
-    char  *optarg[256];      /* optarg[(int) 'f'] holds a pointer to the argument of option "-f" */
-    char  *flags;            /* a list of flag style options supported, e.g. "hv" (help and verbose) */
-    char  *keys;             /* a list of key/value style options supported, e.g. "o" (output) */
-    const char **longflags;  /* long flags, {"help", "verbose"}, or {"h=help", "v=verbose"}, to indicate homologous short options */
-    const char **longkeys;   /* e.g. {"output"} or {o=output"} to support --output=/path/to/output-file. In the latter case, */
-                             /* all operations on "--output" gets redirected to "-o", so user code need handle arguments to "-o" only */
+    int input_index;
+    int record_index;
+    const char *progname; /* argv[0], stripped from /path/to, if present */
+    char flaglevel[21];   /* if flag -f is specified n times, its optarg pointer
+                             is   set to flaglevel + n */
+    char *optarg[256]; /* optarg[(int) 'f'] holds a pointer to the argument of
+                          option "-f" */
+    char *flags; /* a list of flag style options supported, e.g. "hv" (help and
+                    verbose) */
+    char *keys;  /* a list of key/value style options supported, e.g. "o"
+                    (output) */
+    const char *
+        *longflags; /* long flags, {"help", "verbose"}, or {"h=help",
+                       "v=verbose"}, to indicate homologous short options */
+    const char *
+        *longkeys; /* e.g. {"output"} or {o=output"} to support
+                      --output=/path/to/output-file. In the latter case, */
+    /* all operations on "--output" gets redirected to "-o", so user code need
+     * handle arguments to "-o" only */
 };
 
-
 /* name of file currently read from */
-char *opt_filename (OPTARGS *opt) {
-    if (nullptr==opt)
+char *opt_filename(OPTARGS *opt) {
+    if (nullptr == opt)
         return nullptr;
-    if (0==opt->fargc)
+    if (0 == opt->fargc)
         return opt->flaglevel;
     return opt->fargv[opt->input_index];
 }
 
-static int opt_eof (OPTARGS *opt) {
-    if (nullptr==opt)
+static int opt_eof(OPTARGS *opt) {
+    if (nullptr == opt)
         return 1;
-    return feof (opt->input);
+    return feof(opt->input);
 }
 
 /* record number of most recently read record */
-int opt_record (OPTARGS *opt) {
-    if (nullptr==opt)
+int opt_record(OPTARGS *opt) {
+    if (nullptr == opt)
         return 0;
     return opt->record_index + 1;
 }
 
-
 /* handle closing/opening of a "stream-of-streams" */
-int opt_input_loop (OPTARGS *opt, int binary) {
-    if (nullptr==opt)
+int opt_input_loop(OPTARGS *opt, int binary) {
+    if (nullptr == opt)
         return 0;
 
     /* most common case: increment record index and read on */
-    if ( (opt->input!=nullptr) && !feof (opt->input) ) {
+    if ((opt->input != nullptr) && !feof(opt->input)) {
         opt->record_index++;
         return 1;
     }
@@ -264,34 +274,34 @@ int opt_input_loop (OPTARGS *opt, int binary) {
     opt->record_index = 0;
 
     /* no input files specified - read from stdin */
-    if ((0==opt->fargc) && (nullptr==opt->input)) {
+    if ((0 == opt->fargc) && (nullptr == opt->input)) {
         opt->input = stdin;
         return 1;
     }
 
     /* if we're here, we have either reached eof on current input file.   */
     /*  or not yet opened a file. If eof on stdin, we're done             */
-    if (opt->input==stdin)
+    if (opt->input == stdin)
         return 0;
 
     /* end if no more input */
-    if (nullptr!=opt->input)
-        fclose (opt->input);
+    if (nullptr != opt->input)
+        fclose(opt->input);
     if (opt->input_index >= opt->fargc)
         return 0;
 
     /* otherwise, open next input file */
-    opt->input = fopen (opt->fargv[opt->input_index++], binary? "rb": "rt");
+    opt->input = fopen(opt->fargv[opt->input_index++], binary ? "rb" : "rt");
     if (nullptr != opt->input)
         return 1;
 
     /* ignore non-existing files - go on! */
-    return opt_input_loop (opt, binary);
+    return opt_input_loop(opt, binary);
 }
 
-
-/* return true if option with given ordinal is a flag, false if undefined or key=value */
-static int opt_is_flag (OPTARGS *opt, int ordinal) {
+/* return true if option with given ordinal is a flag, false if undefined or
+ * key=value */
+static int opt_is_flag(OPTARGS *opt, int ordinal) {
     if (opt->optarg[ordinal] < opt->flaglevel)
         return 0;
     if (opt->optarg[ordinal] > opt->flaglevel + 20)
@@ -299,192 +309,202 @@ static int opt_is_flag (OPTARGS *opt, int ordinal) {
     return 1;
 }
 
-static int opt_raise_flag (OPTARGS *opt, int ordinal) {
+static int opt_raise_flag(OPTARGS *opt, int ordinal) {
     if (opt->optarg[ordinal] < opt->flaglevel)
         return 1;
     if (opt->optarg[ordinal] > opt->flaglevel + 20)
         return 1;
 
     /* Max out at 20 */
-    if (opt->optarg[ordinal]==opt->flaglevel + 20)
+    if (opt->optarg[ordinal] == opt->flaglevel + 20)
         return 0;
     opt->optarg[ordinal]++;
     return 0;
 }
 
 /* Find the ordinal value of any (short or long) option */
-static int opt_ordinal (OPTARGS *opt, const char *option) {
+static int opt_ordinal(OPTARGS *opt, const char *option) {
     int i;
-    if (nullptr==opt)
+    if (nullptr == opt)
         return 0;
-    if (nullptr==option)
+    if (nullptr == option)
         return 0;
-    if (0==option[0])
+    if (0 == option[0])
         return 0;
     /* An ordinary -o style short option */
-    if (strlen (option)==1) {
+    if (strlen(option) == 1) {
         /* Undefined option? */
-        if (nullptr==opt->optarg[(int) option[0]])
+        if (nullptr == opt->optarg[(int)option[0]])
             return 0;
-        return (int) option[0];
+        return (int)option[0];
     }
 
     /* --longname style long options are slightly harder */
     for (i = 0; i < 64; i++) {
         const char **f = opt->longflags;
-        if (nullptr==f)
+        if (nullptr == f)
             break;
-        if (nullptr==f[i])
+        if (nullptr == f[i])
             break;
-        if (0==strcmp(f[i], "END"))
+        if (0 == strcmp(f[i], "END"))
             break;
-        if (0==strcmp(f[i], option))
+        if (0 == strcmp(f[i], option))
             return 128 + i;
 
         /* long alias? - return ordinal for corresponding short */
-        if ((strlen(f[i]) > 2) && (f[i][1]=='=') && (0==strcmp(f[i]+2, option))) {
-                /* Undefined option? */
-                if (nullptr==opt->optarg[(int) f[i][0]])
-                    return 0;
-                return (int) f[i][0];
+        if ((strlen(f[i]) > 2) && (f[i][1] == '=') &&
+            (0 == strcmp(f[i] + 2, option))) {
+            /* Undefined option? */
+            if (nullptr == opt->optarg[(int)f[i][0]])
+                return 0;
+            return (int)f[i][0];
         }
     }
 
     for (i = 0; i < 64; i++) {
         const char **v = opt->longkeys;
-        if (nullptr==v)
+        if (nullptr == v)
             return 0;
-        if (nullptr==v[i])
+        if (nullptr == v[i])
             return 0;
-        if (0==strcmp (v[i], "END"))
+        if (0 == strcmp(v[i], "END"))
             return 0;
-        if (0==strcmp(v[i], option))
+        if (0 == strcmp(v[i], option))
             return 192 + i;
 
         /* long alias? - return ordinal for corresponding short */
-        if ((strlen(v[i]) > 2) && (v[i][1]=='=') && (0==strcmp(v[i]+2, option))) {
+        if ((strlen(v[i]) > 2) && (v[i][1] == '=') &&
+            (0 == strcmp(v[i] + 2, option))) {
             /* Undefined option? */
-            if (nullptr==opt->optarg[(int) v[i][0]])
+            if (nullptr == opt->optarg[(int)v[i][0]])
                 return 0;
-            return (int) v[i][0];
+            return (int)v[i][0];
         }
-
     }
     /* kill some potential compiler warnings about unused functions */
-    (void) opt_eof (nullptr);
+    (void)opt_eof(nullptr);
     return 0;
 }
 
-
 /* Returns 0 if option was not given on command line, non-0 otherwise */
-int opt_given (OPTARGS *opt, const char *option) {
-    int ordinal = opt_ordinal (opt, option);
-    if (0==ordinal)
+int opt_given(OPTARGS *opt, const char *option) {
+    int ordinal = opt_ordinal(opt, option);
+    if (0 == ordinal)
         return 0;
-    /* For flags we return the number of times the flag was specified (mostly for repeated -v(erbose) flags) */
-    if (opt_is_flag (opt, ordinal))
-        return (int) (opt->optarg[ordinal] - opt->flaglevel);
+    /* For flags we return the number of times the flag was specified (mostly
+     * for repeated -v(erbose) flags) */
+    if (opt_is_flag(opt, ordinal))
+        return (int)(opt->optarg[ordinal] - opt->flaglevel);
     return opt->argv[0] != opt->optarg[ordinal];
 }
 
-
 /* Returns the argument to a given option */
-char *opt_arg (OPTARGS *opt, const char *option) {
-    int ordinal = opt_ordinal (opt, option);
-    if (0==ordinal)
+char *opt_arg(OPTARGS *opt, const char *option) {
+    int ordinal = opt_ordinal(opt, option);
+    if (0 == ordinal)
         return nullptr;
     return opt->optarg[ordinal];
 }
 
-const char *opt_strip_path (const char *full_name) {
+const char *opt_strip_path(const char *full_name) {
     const char *last_path_delim, *stripped_name = full_name;
 
-    last_path_delim = strrchr (stripped_name, '\\');
+    last_path_delim = strrchr(stripped_name, '\\');
     if (last_path_delim > stripped_name)
         stripped_name = last_path_delim + 1;
 
-    last_path_delim = strrchr (stripped_name, '/');
+    last_path_delim = strrchr(stripped_name, '/');
     if (last_path_delim > stripped_name)
         stripped_name = last_path_delim + 1;
     return stripped_name;
 }
 
-/* split command line options into options/flags ("-" style), projdefs ("+" style) and input file args */
-OPTARGS *opt_parse (int argc, char **argv, const char *flags, const char *keys, const char **longflags, const char **longkeys) {
+/* split command line options into options/flags ("-" style), projdefs ("+"
+ * style) and input file args */
+OPTARGS *opt_parse(int argc, char **argv, const char *flags, const char *keys,
+                   const char **longflags, const char **longkeys) {
     int i, j;
     int free_format;
     OPTARGS *o;
 
-    if( argc == 0 )
+    if (argc == 0)
         return nullptr;
 
-    o = (OPTARGS *) calloc (1, sizeof(OPTARGS));
-    if (nullptr==o)
+    o = (OPTARGS *)calloc(1, sizeof(OPTARGS));
+    if (nullptr == o)
         return nullptr;
 
     o->argc = argc;
     o->argv = argv;
-    o->progname = opt_strip_path (argv[0]);
+    o->progname = opt_strip_path(argv[0]);
 
     /* Reset all flags */
-    for (i = 0;  i < (int) strlen (flags);  i++)
-        o->optarg[(int) flags[i]] = o->flaglevel;
+    for (i = 0; i < (int)strlen(flags); i++)
+        o->optarg[(int)flags[i]] = o->flaglevel;
 
-     /* Flag args for all argument taking options as "unset" */
-    for (i = 0; i < (int) strlen (keys); i++)
-        o->optarg[(int) keys[i]] = argv[0];
+    /* Flag args for all argument taking options as "unset" */
+    for (i = 0; i < (int)strlen(keys); i++)
+        o->optarg[(int)keys[i]] = argv[0];
 
     /* Hence, undefined/illegal options have an argument of 0 */
 
-    /* long opts are handled similarly, but are mapped to the high bit character range (above 128) */
-    o->longflags  =  longflags;
-    o->longkeys   =  longkeys;
-
+    /* long opts are handled similarly, but are mapped to the high bit character
+     * range (above 128) */
+    o->longflags = longflags;
+    o->longkeys = longkeys;
 
     /* check aliases, An end user should never experience this, but */
     /* the developer should make sure that aliases are valid */
-    for (i = 0;  longflags && longflags[i]; i++) {
+    for (i = 0; longflags && longflags[i]; i++) {
         /* Go on if it does not look like an alias */
-        if (strlen (longflags[i]) < 3)
+        if (strlen(longflags[i]) < 3)
             continue;
-        if ('='!=longflags[i][1])
+        if ('=' != longflags[i][1])
             continue;
-        if (nullptr==strchr (flags, longflags[i][0])) {
-            fprintf (stderr, "%s: Invalid alias - '%s'. Valid short flags are '%s'\n", o->progname, longflags[i], flags);
-            free (o);
+        if (nullptr == strchr(flags, longflags[i][0])) {
+            fprintf(stderr,
+                    "%s: Invalid alias - '%s'. Valid short flags are '%s'\n",
+                    o->progname, longflags[i], flags);
+            free(o);
             return nullptr;
         }
     }
-    for (i = 0;  longkeys && longkeys[i]; i++) {
+    for (i = 0; longkeys && longkeys[i]; i++) {
         /* Go on if it does not look like an alias */
-        if (strlen (longkeys[i]) < 3)
+        if (strlen(longkeys[i]) < 3)
             continue;
-        if ('='!=longkeys[i][1])
+        if ('=' != longkeys[i][1])
             continue;
-        if (nullptr==strchr (keys, longkeys[i][0])) {
-            fprintf (stderr, "%s: Invalid alias - '%s'. Valid short flags are '%s'\n", o->progname, longkeys[i], keys);
-            free (o);
+        if (nullptr == strchr(keys, longkeys[i][0])) {
+            fprintf(stderr,
+                    "%s: Invalid alias - '%s'. Valid short flags are '%s'\n",
+                    o->progname, longkeys[i], keys);
+            free(o);
             return nullptr;
         }
     }
 
-    /* aside from counting the number of times a flag has been specified, we also abuse the */
-    /* flaglevel array to provide a pseudo-filename for the case of reading from stdin      */
-    strcpy (o->flaglevel, "<stdin>");
+    /* aside from counting the number of times a flag has been specified, we
+     * also abuse the */
+    /* flaglevel array to provide a pseudo-filename for the case of reading from
+     * stdin      */
+    strcpy(o->flaglevel, "<stdin>");
 
-    for (i = 128; (longflags != nullptr) && (longflags[i - 128] != nullptr); i++) {
-        if (i==192) {
-            free (o);
-            fprintf (stderr, "Too many flag style long options\n");
+    for (i = 128; (longflags != nullptr) && (longflags[i - 128] != nullptr);
+         i++) {
+        if (i == 192) {
+            free(o);
+            fprintf(stderr, "Too many flag style long options\n");
             return nullptr;
         }
         o->optarg[i] = o->flaglevel;
     }
 
-    for (i = 192;  (longkeys != nullptr) && (longkeys[i - 192] != nullptr);  i++) {
-        if (i==256) {
-            free (o);
-            fprintf (stderr, "Too many value style long options\n");
+    for (i = 192; (longkeys != nullptr) && (longkeys[i - 192] != nullptr);
+         i++) {
+        if (i == 256) {
+            free(o);
+            fprintf(stderr, "Too many value style long options\n");
             return nullptr;
         }
         o->optarg[i] = argv[0];
@@ -495,48 +515,55 @@ OPTARGS *opt_parse (int argc, char **argv, const char *flags, const char *keys,
     o->argv = argv;
 
     /* Process all '-' and '--'-style options */
-    for (i = 1;  i < argc;  i++) {
-        int arg_group_size = (int) strlen (argv[i]);
+    for (i = 1; i < argc; i++) {
+        int arg_group_size = (int)strlen(argv[i]);
 
         if ('-' != argv[i][0])
             break;
 
-        if (nullptr==o->margv)
+        if (nullptr == o->margv)
             o->margv = argv + i;
         o->margc++;
 
-        for (j = 1;  j < arg_group_size;  j++) {
-            int c =  argv[i][j];
+        for (j = 1; j < arg_group_size; j++) {
+            int c = argv[i][j];
             char cstring[2], *crepr = cstring;
-            cstring[0] = (char) c;
+            cstring[0] = (char)c;
             cstring[1] = 0;
 
-
-            /* Long style flags and options (--long_opt_name, --long_opt_namr arg, --long_opt_name=arg) */
-            if (c== (int)'-') {
+            /* Long style flags and options (--long_opt_name, --long_opt_namr
+             * arg,
+             * --long_opt_name=arg) */
+            if (c == (int)'-') {
                 char *equals;
                 crepr = argv[i] + 2;
 
-                /* We need to manipulate a bit to support gnu style --foo=bar syntax.   */
-                /* NOTE: This will segfault for read-only (const char * style) storage, */
-                /* but since the canonical use case, int main (int argc, char **argv),  */
+                /* We need to manipulate a bit to support gnu style --foo=bar
+                 * syntax. */
+                /* NOTE: This will segfault for read-only (const char * style)
+                 * storage,
+                 */
+                /* but since the canonical use case, int main (int argc, char
+                 * **argv),
+                 */
                 /* is non-const, we ignore this for now */
-                equals = strchr (crepr, '=');
+                equals = strchr(crepr, '=');
                 if (equals)
                     *equals = 0;
-                c = opt_ordinal (o, crepr);
-                if (0==c) {
-                    fprintf (stderr, "Invalid option \"%s\"\n", crepr);
-                    free (o);
+                c = opt_ordinal(o, crepr);
+                if (0 == c) {
+                    fprintf(stderr, "Invalid option \"%s\"\n", crepr);
+                    free(o);
                     return nullptr;
                 }
 
                 /* inline (gnu) --foo=bar style arg */
                 if (equals) {
                     *equals = '=';
-                    if (opt_is_flag (o, c)) {
-                        fprintf (stderr, "Option \"%s\" takes no arguments\n", crepr);
-                        free (o);
+                    if (opt_is_flag(o, c)) {
+                        fprintf(stderr, "Option \"%s\" takes no arguments\n",
+                                crepr);
+                        free(o);
                         return nullptr;
                     }
                     o->optarg[c] = equals + 1;
@@ -544,10 +571,12 @@ OPTARGS *opt_parse (int argc, char **argv, const char *flags, const char *keys,
                 }
 
                 /* "outline" --foo bar style arg */
-                if (!opt_is_flag (o, c)) {
-                    if ((argc==i + 1) || ('+'==argv[i+1][0]) || ('-'==argv[i+1][0])) {
-                        fprintf (stderr, "Missing argument for option \"%s\"\n", crepr);
-                        free (o);
+                if (!opt_is_flag(o, c)) {
+                    if ((argc == i + 1) || ('+' == argv[i + 1][0]) ||
+                        ('-' == argv[i + 1][0])) {
+                        fprintf(stderr, "Missing argument for option \"%s\"\n",
+                                crepr);
+                        free(o);
                         return nullptr;
                     }
                     o->optarg[c] = argv[i + 1];
@@ -555,41 +584,45 @@ OPTARGS *opt_parse (int argc, char **argv, const char *flags, const char *keys,
                     break;
                 }
 
-                if (!opt_is_flag (o, c)) {
-                    fprintf (stderr, "Expected flag style long option here, but got \"%s\"\n", crepr);
-                    free (o);
+                if (!opt_is_flag(o, c)) {
+                    fprintf(stderr,
+                            "Expected flag style long option here, but got "
+                            "\"%s\"\n",
+                            crepr);
+                    free(o);
                     return nullptr;
                 }
 
                 /* Flag style option, i.e. taking no arguments */
-                opt_raise_flag (o, c);
+                opt_raise_flag(o, c);
                 break;
             }
 
             /* classic short options */
-            if (nullptr==o->optarg[c]) {
-                fprintf (stderr, "Invalid option \"%s\"\n", crepr);
-                free (o);
+            if (nullptr == o->optarg[c]) {
+                fprintf(stderr, "Invalid option \"%s\"\n", crepr);
+                free(o);
                 return nullptr;
             }
 
             /* Flag style option, i.e. taking no arguments */
-            if (opt_is_flag (o, c)) {
-                opt_raise_flag (o, c);
+            if (opt_is_flag(o, c)) {
+                opt_raise_flag(o, c);
                 continue;
             }
 
             /* options taking arguments */
 
             /* argument separate (i.e. "-i 10") */
-            if (j + 1==arg_group_size) {
-                if ((argc==i + 1) || ('+'==argv[i+1][0]) || ('-'==argv[i+1][0]))
-                {
-                    fprintf (stderr, "Bad or missing arg for option \"%s\"\n", crepr);
-                    free (o);
+            if (j + 1 == arg_group_size) {
+                if ((argc == i + 1) || ('+' == argv[i + 1][0]) ||
+                    ('-' == argv[i + 1][0])) {
+                    fprintf(stderr, "Bad or missing arg for option \"%s\"\n",
+                            crepr);
+                    free(o);
                     return nullptr;
                 }
-                o->optarg[(int) c] = argv[i + 1];
+                o->optarg[(int)c] = argv[i + 1];
                 i++;
                 break;
             }
@@ -600,13 +633,14 @@ OPTARGS *opt_parse (int argc, char **argv, const char *flags, const char *keys,
         }
     }
 
-    /* Process all '+'-style options, starting from where '-'-style processing ended */
+    /* Process all '+'-style options, starting from where '-'-style processing
+     * ended */
     o->pargv = argv + i;
 
     /* Is free format in use, instead of plus-style? */
     free_format = 0;
-    for (j = 1;  j < argc;  j++) {
-        if (0==strcmp ("--", argv[j])) {
+    for (j = 1; j < argc; j++) {
+        if (0 == strcmp("--", argv[j])) {
             free_format = j;
             break;
         }
@@ -622,8 +656,8 @@ OPTARGS *opt_parse (int argc, char **argv, const char *flags, const char *keys,
 
     for (/* empty */; i < argc; i++) {
         if ('-' == argv[i][0]) {
-            free (o);
-            fprintf (stderr, "+ and - style options must not be mixed\n");
+            free(o);
+            fprintf(stderr, "+ and - style options must not be mixed\n");
             return nullptr;
         }
 
@@ -634,9 +668,8 @@ OPTARGS *opt_parse (int argc, char **argv, const char *flags, const char *keys,
 
     /* Handle input file names */
     o->fargc = argc - i;
-    if (0!=o->fargc)
+    if (0 != o->fargc)
         o->fargv = argv + i;
 
     return o;
-
 }
