@@ -77,6 +77,9 @@
     "Lambert Conic Conformal (2SP Michigan)"
 #define EPSG_CODE_METHOD_LAMBERT_CONIC_CONFORMAL_2SP_MICHIGAN 1051
 
+#define EPSG_NAME_METHOD_AZIMUTHAL_EQUIDISTANT "Azimuthal Equidistant"
+#define EPSG_CODE_METHOD_AZIMUTHAL_EQUIDISTANT 1125
+
 #define EPSG_NAME_METHOD_MODIFIED_AZIMUTHAL_EQUIDISTANT                        \
     "Modified Azimuthal Equidistant"
 #define EPSG_CODE_METHOD_MODIFIED_AZIMUTHAL_EQUIDISTANT 9832
@@ -105,6 +108,9 @@
 
 #define PROJ_WKT2_NAME_METHOD_EQUIDISTANT_CONIC "Equidistant Conic"
 
+#define EPSG_NAME_METHOD_EQUIDISTANT_CONIC "Equidistant Conic"
+#define EPSG_CODE_METHOD_EQUIDISTANT_CONIC 1119
+
 #define PROJ_WKT2_NAME_METHOD_ECKERT_I "Eckert I"
 
 #define PROJ_WKT2_NAME_METHOD_ECKERT_II "Eckert II"
@@ -167,6 +173,13 @@
 #define EPSG_NAME_METHOD_KROVAK "Krovak"
 #define EPSG_CODE_METHOD_KROVAK 9819
 
+#define EPSG_NAME_METHOD_KROVAK_MODIFIED "Krovak Modified"
+#define EPSG_CODE_METHOD_KROVAK_MODIFIED 1042
+
+#define EPSG_NAME_METHOD_KROVAK_MODIFIED_NORTH_ORIENTED                        \
+    "Krovak Modified (North Orientated)"
+#define EPSG_CODE_METHOD_KROVAK_MODIFIED_NORTH_ORIENTED 1043
+
 #define EPSG_NAME_METHOD_LAMBERT_AZIMUTHAL_EQUAL_AREA                          \
     "Lambert Azimuthal Equal Area"
 #define EPSG_CODE_METHOD_LAMBERT_AZIMUTHAL_EQUAL_AREA 9820
@@ -187,6 +200,9 @@
     "Popular Visualisation Pseudo Mercator"
 #define EPSG_CODE_METHOD_POPULAR_VISUALISATION_PSEUDO_MERCATOR 1024
 
+#define EPSG_NAME_METHOD_MERCATOR_SPHERICAL "Mercator (Spherical)"
+#define EPSG_CODE_METHOD_MERCATOR_SPHERICAL 1026
+
 #define PROJ_WKT2_NAME_METHOD_MOLLWEIDE "Mollweide"
 
 #define PROJ_WKT2_NAME_METHOD_NATURAL_EARTH "Natural Earth"
@@ -575,6 +591,27 @@
 
 /* ------------------------------------------------------------------------ */
 
+#define EPSG_NAME_METHOD_POINT_MOTION_BY_GRID_CANADA_NTV2_VEL                  \
+    "Point motion by grid (Canada NTv2_Vel)"
+#define EPSG_CODE_METHOD_POINT_MOTION_BY_GRID_CANADA_NTV2_VEL 1070
+
+#define EPSG_CODE_PARAMETER_POINT_MOTION_VELOCITY_GRID_FILE 1050
+#define EPSG_NAME_PARAMETER_POINT_MOTION_VELOCITY_GRID_FILE                    \
+    "Point motion velocity grid file"
+
+/* ------------------------------------------------------------------------ */
+#define EPSG_NAME_METHOD_GEOGRAPHIC3D_OFFSET_BY_VELOCITY_GRID_NRCAN            \
+    "Geographic3D Offset by velocity grid (NRCan byn)"
+#define EPSG_CODE_METHOD_GEOGRAPHIC3D_OFFSET_BY_VELOCITY_GRID_NRCAN 1114
+
+/* ------------------------------------------------------------------------ */
+
+#define EPSG_NAME_METHOD_VERTICAL_OFFSET_BY_VELOCITY_GRID_NRCAN                \
+    "Vertical Offset by velocity grid (NRCan NTv2_Vel)"
+#define EPSG_CODE_METHOD_VERTICAL_OFFSET_BY_VELOCITY_GRID_NRCAN 1113
+
+/* ------------------------------------------------------------------------ */
+
 #define PROJ_WKT2_NAME_METHOD_HEIGHT_TO_GEOG3D                                 \
     "GravityRelatedHeight to Geographic3D"
 
@@ -610,6 +647,8 @@
 #define EPSG_NAME_METHOD_VERTICALGRID_PL_TXT                                   \
     "Vertical Offset by Grid Interpolation (PL txt)"
 
+/* has been deprecated by
+ * EPSG_CODE_METHOD_VERTICALCHANGE_BY_GEOID_GRID_DIFFERENCE_NRCAN */
 #define EPSG_CODE_METHOD_VERTICALGRID_NRCAN_BYN 1112
 #define EPSG_NAME_METHOD_VERTICALGRID_NRCAN_BYN                                \
     "Vertical Offset by Grid Interpolation (NRCan byn)"
@@ -617,6 +656,14 @@
 #define EPSG_NAME_PARAMETER_VERTICAL_OFFSET_FILE "Vertical offset file"
 #define EPSG_CODE_PARAMETER_VERTICAL_OFFSET_FILE 8732
 
+#define EPSG_CODE_METHOD_VERTICALCHANGE_BY_GEOID_GRID_DIFFERENCE_NRCAN 1126
+#define EPSG_NAME_METHOD_VERTICALCHANGE_BY_GEOID_GRID_DIFFERENCE_NRCAN         \
+    "Vertical change by geoid grid difference (NRCan)"
+
+#define EPSG_NAME_PARAMETER_GEOID_MODEL_DIFFERENCE_FILE                        \
+    "Geoid model difference file"
+#define EPSG_CODE_PARAMETER_GEOID_MODEL_DIFFERENCE_FILE 1063
+
 /* ------------------------------------------------------------------------ */
 
 #define EPSG_CODE_METHOD_NADCON 9613
