@@ -1,4 +1,4 @@
-#define PJ_LIB_
+
 
 #include <errno.h>
 #include <math.h>
@@ -10,7 +10,7 @@ PROJ_HEAD(poly, "Polyconic (American)")
 "\n\tConic, Sph&Ell";
 
 namespace { // anonymous namespace
-struct pj_opaque {
+struct pj_poly_data {
     double ml0;
     double *en;
 };
@@ -24,7 +24,7 @@ struct pj_opaque {
 
 static PJ_XY poly_e_forward(PJ_LP lp, PJ *P) { /* Ellipsoidal, forward */
     PJ_XY xy = {0.0, 0.0};
-    struct pj_opaque *Q = static_cast<struct pj_opaque *>(P->opaque);
+    struct pj_poly_data *Q = static_cast<struct pj_poly_data *>(P->opaque);
     double ms, sp, cp;
 
     if (fabs(lp.phi) <= TOL) {
@@ -45,7 +45,7 @@ static PJ_XY poly_e_forward(PJ_LP lp, PJ *P) { /* Ellipsoidal, forward */
 
 static PJ_XY poly_s_forward(PJ_LP lp, PJ *P) { /* Spheroidal, forward */
     PJ_XY xy = {0.0, 0.0};
-    struct pj_opaque *Q = static_cast<struct pj_opaque *>(P->opaque);
+    struct pj_poly_data *Q = static_cast<struct pj_poly_data *>(P->opaque);
 
     if (fabs(lp.phi) <= TOL) {
         xy.x = lp.lam;
@@ -62,7 +62,7 @@ static PJ_XY poly_s_forward(PJ_LP lp, PJ *P) { /* Spheroidal, forward */
 
 static PJ_LP poly_e_inverse(PJ_XY xy, PJ *P) { /* Ellipsoidal, inverse */
     PJ_LP lp = {0.0, 0.0};
-    struct pj_opaque *Q = static_cast<struct pj_opaque *>(P->opaque);
+    struct pj_poly_data *Q = static_cast<struct pj_poly_data *>(P->opaque);
 
     xy.y += Q->ml0;
     if (fabs(xy.y) <= TOL) {
@@ -138,27 +138,27 @@ static PJ_LP poly_s_inverse(PJ_XY xy, PJ *P) { /* Spheroidal, inverse */
     return lp;
 }
 
-static PJ *destructor(PJ *P, int errlev) {
+static PJ *pj_poly_destructor(PJ *P, int errlev) {
     if (nullptr == P)
         return nullptr;
 
     if (nullptr == P->opaque)
         return pj_default_destructor(P, errlev);
 
-    if (static_cast<struct pj_opaque *>(P->opaque)->en)
-        free(static_cast<struct pj_opaque *>(P->opaque)->en);
+    if (static_cast<struct pj_poly_data *>(P->opaque)->en)
+        free(static_cast<struct pj_poly_data *>(P->opaque)->en);
 
     return pj_default_destructor(P, errlev);
 }
 
-PJ *PROJECTION(poly) {
-    struct pj_opaque *Q =
-        static_cast<struct pj_opaque *>(calloc(1, sizeof(struct pj_opaque)));
+PJ *PJ_PROJECTION(poly) {
+    struct pj_poly_data *Q = static_cast<struct pj_poly_data *>(
+        calloc(1, sizeof(struct pj_poly_data)));
     if (nullptr == Q)
         return pj_default_destructor(P, PROJ_ERR_OTHER /*ENOMEM*/);
 
     P->opaque = Q;
-    P->destructor = destructor;
+    P->destructor = pj_poly_destructor;
 
     if (P->es != 0.0) {
         if (!(Q->en = pj_enfn(P->n)))
@@ -174,3 +174,9 @@ PJ *PROJECTION(poly) {
 
     return P;
 }
+
+#undef TOL
+#undef CONV
+#undef N_ITER
+#undef I_ITER
+#undef ITOL
